job

# XMLRésuméLibrary: User Guide

interests | Element Reference | jobtitle

## Name

job — A specific employment engagement

## Synopsis

### Content Model

    (jobtitle,employer,location?,(date|period),description?,projects?,achievements?)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `job` element describes a job, contract, or other employment engagement.

### Parents

`job` may be contained in these elements: `history`

### Attributes

`id`

  A string used to uniquely identify a job. The job may then be referred to by this identifier.

## Examples

    <job>
      <jobtitle>Sr. VP of Soap Suds Engineering</jobtitle>
      <employer>Proctor and Gamble</employer>
      <period>
        <from><date>
          <month>May</month>
          <year>1982</year>
        </date></from>
        <to><date>
          <month>June</month>
          <year>1988</year>
        </date></to>
      </period>
    </job>

    <job>
      <jobtitle>Dirt</jobtitle>
      <employer>Earth</employer>
      <period>
        <from><date>
          <month>Januaray</month>
          <year>30,000 B.C.</year>
        </date></from>
        <to><present/></to>
      </period>
      <description>
        Provided nutrients, absorbed water, and got tracked into houses.
      </description>
      <achievements>
        <achievement>
          Grew a 300-ft. tree.
        </achievement>
      </achievements>
      <projects>
        <project>
          Took part in the construction of the construction of the Empire State
          Building in New York City. (Was excavated from its basement.)
        </project>
      </projects>
    </job>

interests | Element Reference | jobtitle